summaryrefslogtreecommitdiffstats
path: root/libnetdata
diff options
context:
space:
mode:
authorAndrew Moss <1043609+amoss@users.noreply.github.com>2020-06-12 17:49:53 +0200
committerGitHub <noreply@github.com>2020-06-12 17:49:53 +0200
commit68f1888227bac1602d8777742995e0276bf05510 (patch)
treef249d428a9a1b92edd5fc1a29ee1264740f3dfd1 /libnetdata
parent777818f5b909aa982415968c55cf073e867e9950 (diff)
Change streaming terminology to parent-child in the code (#9323)
Diffstat (limited to 'libnetdata')
-rw-r--r--libnetdata/socket/security.c10
1 files changed, 5 insertions, 5 deletions
diff --git a/libnetdata/socket/security.c b/libnetdata/socket/security.c
index de945e69fe..2f340ad996 100644
--- a/libnetdata/socket/security.c
+++ b/libnetdata/socket/security.c
@@ -316,7 +316,7 @@ int security_process_accept(SSL *ssl,int msg) {
/**
* Test Certificate
*
* Check the certificate of Netdata master
*
* @param ssl is the connection structure
*
@@ -348,10 +348,10 @@ int security_test_certificate(SSL *ssl) {
* Location for context
*
* Case the user give us a directory with the certificates available and
* the Netdata master certificate, we use this function to validate the certificate.
*
* @param ctx the context where the path will be set.
* @param file the file with Netdata master certificate.
* @param path the directory where the certificates are stored.
*
* @return It returns 0 on success and -1 otherwise.
@@ -359,7 +359,7 @@ int security_test_certificate(SSL *ssl) {
int security_location_for_context(SSL_CTX *ctx, char *file, char *path) {
struct stat statbuf;
if (stat(file, &statbuf)) {
- info("Netdata does not have a SSL master certificate, so it will use the default OpenSSL configuration to validate certificates!");
+ info("Netdata does not have the parent's SSL certificate, so it will use the default OpenSSL configuration to validate certificates!");
return 0;
}
@@ -379,7 +379,7 @@ int security_location_for_context(SSL_CTX *ctx, char *file, char *path) {
slfc:
while ((err = ERR_get_error()) != 0) {
ERR_error_string_n(err, buf, sizeof(buf));
- error("Cannot set the directory for the certificates and the master SSL certificate: %s",buf);
+ error("Cannot set the directory for the certificates and the parent SSL certificate: %s",buf);
}
return -1;
}
@@ -316,7 +316,7 @@ int security_process_accept(SSL *ssl,int msg) {
* Test Certificate
*
- * Check the certificate of Netdata master
+ * Check the certificate of Netdata parent
*
* @param ssl is the connection structure
@@ -348,10 +348,10 @@ int security_test_certificate(SSL *ssl) {
*
* Case the user give us a directory with the certificates available and
- * the Netdata master certificate, we use this function to validate the certificate.
+ * the Netdata parent certificate, we use this function to validate the certificate.
*
* @param ctx the context where the path will be set.
@@ -348,10 +348,10 @@ int security_test_certificate(SSL *ssl) {
*
* @param ctx the context where the path will be set.
- * @param file the file with Netdata master certificate.
+ * @param file the file with Netdata parent certificate.
* @param path the directory where the certificates are stored.
*